powered by
Post new data to a deployed model API endpoint and return predictions
# S3 method for vetiver_endpoint predict(object, new_data, ...)
A tibble of model predictions with as many rows as in new_data.
new_data
A model API endpoint object created with vetiver_endpoint().
vetiver_endpoint()
New data for making predictions, such as a data frame.
Extra arguments passed to httr::POST()
httr::POST()
augment.vetiver_endpoint()
if (FALSE) { endpoint <- vetiver_endpoint("http://127.0.0.1:8088/predict") predict(endpoint, mtcars[4:7, -1]) }
Run the code above in your browser using DataLab