Learn R Programming

vetiver (version 0.2.7)

vetiver-package: vetiver: Version, Share, Deploy, and Monitor Models

Description

logo

The goal of 'vetiver' is to provide fluent tooling to version, share, deploy, and monitor a trained model. Functions handle both recording and checking the model's input data prototype, and predicting from a remote API endpoint. The 'vetiver' package is extensible, with generics that can support many kinds of models.

Arguments

Author

Maintainer: Julia Silge julia.silge@posit.co (ORCID)

Other contributors:

  • Posit Software, PBC (ROR) [copyright holder, funder]

See Also