Use vetiver_create_rsconnect_bundle() to create a
Posit Connect model API bundle for a
vetiver_model() that has been versioned and stored via
vetiver_pin_write().
vetiver_create_rsconnect_bundle(
board,
name,
version = NULL,
predict_args = list(),
filename = fs::file_temp(pattern = "bundle", ext = ".tar.gz"),
additional_pkgs = character(0)
)The location of the model API bundle filename, invisibly.
A pin board, created by board_folder(), board_connect(),
board_url() or another board_ function.
Pin name.
Retrieve a specific version of a pin. Use pin_versions() to
find out which versions are available and when they were created.
A list of optional arguments passed to vetiver_api()
such as the prediction type.
The path for the model API bundle to be created (can be
used as the argument to connectapi::bundle_path())
Any additional R packages that need to be attached
via library() to run your API, as a character vector.
This function creates a deployable bundle. See Posit Connect docs for how to deploy this bundle, as well as the connectapi R package for how to integrate with Connect's API from R.
The two functions vetiver_create_rsconnect_bundle() and
vetiver_deploy_rsconnect() are alternatives to each other, providing
different strategies for deploying a vetiver model API to Posit Connect.
vetiver_write_plumber(), vetiver_deploy_rsconnect()