These three functions can be used for model monitoring (such as in a monitoring dashboard):
vetiver_compute_metrics() computes metrics (such as accuracy for a
classification model or RMSE for a regression model) at a chosen time
aggregation period
vetiver_pin_metrics() updates an existing pin storing model metrics
over time
vetiver_plot_metrics() creates a plot of metrics over time
vetiver_plot_metrics(
df_metrics,
.index = .index,
.estimate = .estimate,
.metric = .metric,
.n = .n
)A ggplot2 object.
A tidy dataframe of metrics over time, such as created by
vetiver_compute_metrics().
The variable in df_metrics containing the aggregated dates
or date-times (from time_var in data). Defaults to .index.
The variable in df_metrics containing the metric estimate.
Defaults to .estimate.
The variable in df_metrics containing the metric type.
Defaults to .metric.
The variable in df_metrics containing the number of observations
used for estimating the metric.
vetiver_compute_metrics(), vetiver_pin_metrics()